@@ -4,7 +4,7 @@ use warnings FATAL => qw(all);
 use 5.010; no if $] >= 5.017011, warnings => "experimental";
 
 use Carp qw(carp croak confess);
-our $VERSION = '0.0_9'; # ShipIt do not understand qv().
+our $VERSION = '0.0.9_001'; # ShipIt do not understand qv().
 #use mro 'c3';
 
 use Scalar::Util qw/weaken/;
@@ -19,6 +19,7 @@ use YATT::Lite::MFields qw/YATT
 	      cf_factory
 	      cf_output_encoding
 	      cf_tmpl_encoding
+	      cf_index_name
 	      cf_app_ns entns
 	      cf_app_name
 	      cf_debug_cgen cf_debug_parser cf_namespace cf_only_parse
@@ -50,12 +51,14 @@ use YATT::Lite::Util qw/globref lexpand extname ckrequire terse_dump escape
 			look_for_globref
 			subname ckeval
 			secure_text_plain
+			define_const
 		       /;
 
 sub Facade () {__PACKAGE__}
 sub default_app_ns {'MyApp'}
 sub default_trans {'YATT::Lite::Core'}
 sub default_export {(shift->SUPER::default_export, qw(Entity *SYS *CON))}
+sub default_index_name { '' }
 
 sub with_system {
   (my MY $self, local $SYS, my $method) = splice @_, 0, 3;
@@ -65,6 +68,7 @@ sub with_system {
 sub after_new {
   (my MY $self) = @_;
   $self->SUPER::after_new;
+  $self->{cf_index_name} //= "";
   weaken($self->{cf_factory});
 }
 
@@ -279,6 +283,7 @@ sub build_trans {
 				     die_in_error tmpl_encoding
 				     debug_cgen debug_parser
 				     special_entities no_lineinfo check_lineno
+				     index_name
 				     rc_script
 				     lcmsg_sink
 				     only_parse/));
@@ -332,7 +337,7 @@ sub ensure_entns {
 
   # EntNS() を足すのは最後にしないと、再帰継承に陥る
   unless (my $code = *{$sym}{CODE}) {
-    *$sym = sub () { $entns };
+    define_const($sym, $entns);
   } elsif ((my $old = $code->()) ne $entns) {
     croak "Can't add EntNS() to '$app_ns'. Already has EntNS as $old!";
   } else {
