@@ -18,6 +18,7 @@ require Scalar::Util;
 		     nonempty
 		     subname
 		     pkg2pm
+		     globref_default
 		   /;
   }
   use Carp;
@@ -37,11 +38,29 @@ require Scalar::Util;
     defined $_[0] && $_[0] ne '';
   }
 
+  sub define_const {
+    my ($name_or_glob, $value) = @_;
+    my $glob = ref $name_or_glob ? $name_or_glob : globref($name_or_glob);
+    *$glob = my $const_sub = sub () { $value };
+    $const_sub;
+  }
+
   sub globref {
-    my ($thing, $name) = @_;
+    my ($thing, @name) = @_;
     my $class = ref $thing || $thing;
     no strict 'refs';
-    \*{join("::", $class, defined $name ? $name : ())};
+    \*{join("::", $class, grep {defined} @name)};
+  }
+  sub globref_default {
+    unless (@_ == 2) {
+      croak "Too few arguments";
+    }
+    my ($globref, $default) = @_;
+    my $kind = ref $default;
+    *{$globref}{$kind} || do {
+      *{$globref} = $default;
+      $default;
+    };
   }
   sub symtab {
     *{globref(shift, '')}{HASH}
@@ -437,12 +456,16 @@ sub named_attr {
 }
 
 {
-  our %input_types = qw!select 0 radio 1 checkbox 2!;
+  our %input_spec = (select => [0, 0]
+		     , radio => [1, 0]
+		     , checkbox => [2, 1]);
   sub att_value_in {
     my ($in, $type, $name, $formal_value, $as_value) = @_;
-    defined (my $typeid = $input_types{$type})
+    defined (my $spec = $input_spec{$type})
       or croak "Unknown type: $type";
 
+    my ($typeid, $has_sfx) = @$spec;
+
     unless (defined $name and $name ne '') {
       croak "name is empty";
     }
@@ -458,11 +481,11 @@ sub named_attr {
     }
 
     if ($typeid) {
-      my $sfx = $typeid ? '['.escape($formal_value).']' : '';
+      my $sfx = $has_sfx ? '['.escape($formal_value).']' : '';
       push @res, qq|name="@{[escape($name)]}$sfx"|;
     }
 
-    if (not $typeid) {
+    if (not $has_sfx) {
       # select
       push @res, qq|value="@{[escape($formal_value)]}"|;
     } elsif ($as_value) {
@@ -684,7 +707,7 @@ sub shallow_copy {
   }
 }
 
-if (catch {require Sub::Name}) {
+if (not is_debugging() or catch {require Sub::Name}) {
   *subname = sub { my ($name, $sub) = @_; $sub }
 } else {
   *subname = *Sub::Name::subname;
@@ -792,7 +815,7 @@ sub pkg2pm {
 # to put all functions into @EXPORT_OK.
 #
 {
-  our @EXPORT_OK;
+  our @EXPORT_OK = qw(define_const);
   my $symtab = symtab(__PACKAGE__);
   foreach my $name (grep {/^[a-z]/} keys %$symtab) {
     my $glob = $symtab->{$name};
